import { CodeAction, CodeActionContext, CompletionContext, DefinitionLink, Diagnostic, Hover, Location, Position, Range, ReferenceContext, SymbolInformation, WorkspaceEdit, SelectionRange, SignatureHelp, SignatureHelpContext, SemanticTokens, TextDocumentContentChangeEvent } from 'vscode-languageserver';
import { Document, DocumentManager } from '../../lib/documents';
import { LSConfigManager } from '../../ls-config';
import { AppCompletionItem, AppCompletionList, CodeActionsProvider, CompletionsProvider, DefinitionsProvider, DiagnosticsProvider, DocumentSymbolsProvider, FileRename, FindReferencesProvider, HoverProvider, OnWatchFileChanges, RenameProvider, SelectionRangeProvider, SignatureHelpProvider, UpdateImportsProvider, OnWatchFileChangesPara, SemanticTokensProvider, UpdateTsOrJsFile } from '../interfaces';
import { CompletionEntryWithIdentifer } from './features/CompletionProvider';
import { SnapshotManager } from './SnapshotManager';
export declare class TypeScriptPlugin implements DiagnosticsProvider, HoverProvider, DocumentSymbolsProvider, DefinitionsProvider, CodeActionsProvider, UpdateImportsProvider, RenameProvider, FindReferencesProvider, SelectionRangeProvider, SignatureHelpProvider, SemanticTokensProvider, OnWatchFileChanges, CompletionsProvider<CompletionEntryWithIdentifer>, UpdateTsOrJsFile {
    private readonly configManager;
    private readonly lsAndTsDocResolver;
    private readonly completionProvider;
    private readonly codeActionsProvider;
    private readonly updateImportsProvider;
    private readonly diagnosticsProvider;
    private readonly renameProvider;
    private readonly hoverProvider;
    private readonly findReferencesProvider;
    private readonly selectionRangeProvider;
    private readonly signatureHelpProvider;
    private readonly semanticTokensProvider;
    constructor(docManager: DocumentManager, configManager: LSConfigManager, workspaceUris: string[], isEditor?: boolean);
    getDiagnostics(document: Document): Promise<Diagnostic[]>;
    doHover(document: Document, position: Position): Promise<Hover | null>;
    getDocumentSymbols(document: Document): Promise<SymbolInformation[]>;
    getCompletions(document: Document, position: Position, completionContext?: CompletionContext): Promise<AppCompletionList<CompletionEntryWithIdentifer> | null>;
    resolveCompletion(document: Document, completionItem: AppCompletionItem<CompletionEntryWithIdentifer>): Promise<AppCompletionItem<CompletionEntryWithIdentifer>>;
    getDefinitions(document: Document, position: Position): Promise<DefinitionLink[]>;
    prepareRename(document: Document, position: Position): Promise<Range | null>;
    rename(document: Document, position: Position, newName: string): Promise<WorkspaceEdit | null>;
    getCodeActions(document: Document, range: Range, context: CodeActionContext): Promise<CodeAction[]>;
    executeCommand(document: Document, command: string, args?: any[]): Promise<WorkspaceEdit | null>;
    updateImports(fileRename: FileRename): Promise<WorkspaceEdit | null>;
    findReferences(document: Document, position: Position, context: ReferenceContext): Promise<Location[] | null>;
    onWatchFileChanges(onWatchFileChangesParas: OnWatchFileChangesPara[]): Promise<void>;
    updateTsOrJsFile(fileName: string, changes: TextDocumentContentChangeEvent[]): Promise<void>;
    getSelectionRange(document: Document, position: Position): Promise<SelectionRange | null>;
    getSignatureHelp(document: Document, position: Position, context: SignatureHelpContext | undefined): Promise<SignatureHelp | null>;
    getSemanticTokens(textDocument: Document, range?: Range): Promise<SemanticTokens | null>;
    private getLSAndTSDoc;
    /**
     *
     * @internal
     */
    getSnapshotManager(fileName: string): Promise<SnapshotManager>;
    private featureEnabled;
}
