import { Diagnostic } from 'vscode-languageserver';
export declare type SvelteCheckDiagnosticSource = 'js' | 'css' | 'svelte';
export interface SvelteCheckOptions {
    compilerWarnings?: Record<string, 'ignore' | 'error'>;
    diagnosticSources?: SvelteCheckDiagnosticSource[];
}
/**
 * Small wrapper around PluginHost's Diagnostic Capabilities
 * for svelte-check, without the overhead of the lsp.
 */
export declare class SvelteCheck {
    private docManager;
    private configManager;
    private pluginHost;
    constructor(workspacePath: string, options?: SvelteCheckOptions);
    private initialize;
    /**
     * Creates/updates given document
     *
     * @param doc Text and Uri of the document
     */
    upsertDocument(doc: {
        text: string;
        uri: string;
    }): void;
    /**
     * Removes/closes document
     *
     * @param uri Uri of the document
     */
    removeDocument(uri: string): void;
    /**
     * Gets the diagnostics for all currently open files.
     */
    getDiagnostics(): Promise<Array<{
        filePath: string;
        text: string;
        diagnostics: Diagnostic[];
    }>>;
}
